@@ -11,11 +11,11 @@
  *                MdcDebugPrint()    - Print MDC_MY_DEBUG info             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-debug.c,v 1.61 2006/12/05 22:47:44 enlf Exp $
+/* $Id: m-debug.c,v 1.64 2007/06/05 21:02:45 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -144,6 +144,8 @@ void MdcPrintFI(FILEINFO *fi)
   MdcPrntScrn("patient_id         : %s\n",fi->patient_id);
   MdcPrntScrn("patient_dob        : %s\n",fi->patient_dob);
   MdcPrntScrn("patient_weight     : %.2f [kg]\n",fi->patient_weight);
+  MdcPrntScrn("patient_height     : %.2f [m]\n",fi->patient_height);
+  MdcPrntScrn("operator_name      : %s\n",fi->operator_name);
   MdcPrntScrn("study_descr        : %s\n",fi->study_descr);
   MdcPrntScrn("study_id           : %s\n",fi->study_id);
   MdcPrntScrn("study_date_year    : %02d\n",fi->study_date_year);
@@ -155,13 +157,13 @@ void MdcPrintFI(FILEINFO *fi)
   MdcPrntScrn("dose_time_hour     : %02d\n",fi->dose_time_hour);
   MdcPrntScrn("dose_time_minute   : %02d\n",fi->dose_time_minute);
   MdcPrntScrn("dose_time_second   : %02d\n",fi->dose_time_second);
-  MdcPrntScrn("nr_series          : %-5hd ",fi->nr_series);
+  MdcPrntScrn("nr_series          : %-10d ",fi->nr_series);
   if (fi->nr_series < 0) MdcPrintYesNo(MDC_NO);
   else MdcPrintYesNo(MDC_YES);
-  MdcPrntScrn("nr_acquisition     : %-5hd ",fi->nr_acquisition);
+  MdcPrntScrn("nr_acquisition     : %-10d ",fi->nr_acquisition);
   if (fi->nr_acquisition < 0) MdcPrintYesNo(MDC_NO);
   else MdcPrintYesNo(MDC_YES);
-  MdcPrntScrn("nr_instance        : %-5hd ",fi->nr_instance);
+  MdcPrntScrn("nr_instance        : %-10d ",fi->nr_instance);
   if (fi->nr_instance < 0) MdcPrintYesNo(MDC_NO);
   else MdcPrintYesNo(MDC_YES);
   v = fi->acquisition_type;
