@@ -18,11 +18,11 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.173 2006/12/05 22:41:23 enlf Exp $
+/* $Id: m-dicm.c,v 1.178 2007/06/07 21:50:45 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -61,7 +61,7 @@
                               D E F I N E S
 ****************************************************************************/
 
-#define MDC_STR_UID_CREATOR   "777.777.0.0.0.0.0"
+#define MDC_STR_UID_CREATOR   "777.777.0.0.0"
 
 #define UNDEFINED_LENGTH      0xffffffff
 
@@ -111,10 +111,10 @@ static int MDC_DICOM_VERBOSE = MDC_YES;
 static Uint32 MDC_REWRF_SLOPE;         /* rewrite offset to slope     tag */
 static Uint32 MDC_REWRF_INTERCEPT;     /* rewrite offset to intercept tag */
 
-static time_t mdc_sec, *mdc_psec=NULL; /* universal time */
+static Int32 mdc_prev_nr_series = -MDC_TYPE_UID_SERIES;
+static Int32 mdc_prev_series_uid = 0;
 
-static Int16 mdc_incrinstance =  0;
-static Int16 mdc_previnstance = -1;
+static time_t mdc_sec, *mdc_psec=NULL; /* universal time */
 
 static char mdc_dummy1[]="1";
 
@@ -621,8 +621,7 @@ Uint32 MdcDicomMakeUID(FILEINFO *fi, Int8 uid, char str[])
 {
   Int16 year, month, day;
   Int16 hour, minute, second;
-  Int16 series, acquisition, instance;
-  Uint32 utc, len;
+  Uint32 utc, len, study_uid, series_uid, instance_uid;
 
   year  = fi->study_date_year;
   month = fi->study_date_month;
@@ -631,62 +630,66 @@ Uint32 MdcDicomMakeUID(FILEINFO *fi, Int8 uid, char str[])
   minute= fi->study_time_minute;
   second= fi->study_time_second;
 
-  series      = (fi->nr_series      > 0) ? fi->nr_series      : 0;
-  acquisition = (fi->nr_acquisition > 0) ? fi->nr_acquisition : 0;
-  instance    = (fi->nr_instance    > 0) ? fi->nr_instance    : 0;
-
   if (mdc_psec != NULL) {
     utc = (Uint32)*mdc_psec;
   }else{
     utc = 777UL;
-  } 
+  }  
 
+  /* study_uid = hash(patient_name + study_date + study_time) */
+  sprintf(str,"%s%s%hd%02hd%02hd%02hd%02hd%02hd"
+             ,fi->patient_name,fi->patient_id
+             ,year,month,day,hour,minute,second);
+  study_uid = MdcHashSDBM((unsigned char *)str);
+  if (study_uid == 182208422) { /* Unknown000000000 case */
+    sprintf(str,"%u",utc);
+    study_uid = MdcHashSDBM((unsigned char *)str); 
+  }
+ 
+  /* series_uid = hash(input filename)*/
+  if (mdc_prev_nr_series == -MDC_TYPE_UID_SERIES) {
+    mdc_prev_nr_series = fi->nr_series;
+    series_uid = MdcHashSDBM((unsigned char *)fi->ifname);
+    mdc_prev_series_uid = series_uid;
+  }
+
+  /* new series_uid for each input file */
+  if ((fi->nr_series != mdc_prev_nr_series) || (fi->nr_series <= 0)) {
+    mdc_prev_nr_series = fi->nr_series;
+    series_uid = MdcHashSDBM((unsigned char*)fi->ifname);
+    mdc_prev_series_uid = series_uid;
+  }else{
+    series_uid = mdc_prev_series_uid;
+  }
+ 
+  /* new instance_uid for each output file */
+  instance_uid = MdcHashSDBM((unsigned char *)fi->ofname);
+ 
   switch (uid) {
     case MDC_TYPE_UID_CREATOR:
         sprintf(str,"%s",MDC_STR_UID_CREATOR);
         break;
     case MDC_TYPE_UID_SOP_INSTANCE:
-        series = mdc_incrinstance;
-        sprintf(str,"%s.%u%hd%02hd%02hd%02hd%02hd%02hd%05hd%05hd%05hd"
-                   ,MDC_STR_UID_CREATOR,utc
-                   ,year,month,day,hour,minute,second
-                   ,series,acquisition,instance);
-        break;
     case MDC_TYPE_UID_MEDIA_INSTANCE:
-        if (mdc_previnstance == -1) {
-          /* preserve first time value */
-          mdc_previnstance = series; mdc_incrinstance = series;
-        }else if ((series == 0) && (acquisition == 0) && (instance == 0)) {
-          /* automatically increment for missing numbers */
-          mdc_incrinstance += 1;
-        }else if (instance == mdc_previnstance) {
-          /* automatically increment for equal   numbers */
-          mdc_incrinstance += 1;
-          instance = mdc_incrinstance;
-        }
-        series = mdc_incrinstance;
-        sprintf(str,"%s.%u%hd%02hd%02hd%02hd%02hd%02hd%05hd%05hd%05hd"
+        sprintf(str,"%s.%u.%u.%u.%u"
                    ,MDC_STR_UID_CREATOR,utc
-                   ,year,month,day,hour,minute,second
-                   ,series,acquisition,instance);
+                   ,study_uid,series_uid,instance_uid);
         break;
     case MDC_TYPE_UID_FRAME:
     case MDC_TYPE_UID_STUDY:
-        sprintf(str,"%s.%u%hd%02hd%02hd%02hd%02hd%02hd"
+        sprintf(str,"%s.%u.%u"
                    ,MDC_STR_UID_CREATOR,utc
-                   ,year,month,day,hour,minute,second);
+                   ,study_uid);
         break;
     case MDC_TYPE_UID_SERIES:
-        series = mdc_incrinstance;
-        sprintf(str,"%s.%u%hd%02hd%02hd%02hd%02hd%02hd%05hd"
+        sprintf(str,"%s.%u.%u.%u"
                    ,MDC_STR_UID_CREATOR,utc
-                   ,year,month,day,hour,minute,second
-                   ,series);
+                   ,study_uid,series_uid);
         break;
     default:
-        sprintf(str,"%s.%u%hd%02hd%02hd%02hd%02hd%02hd"
+        sprintf(str,"%s.%u.%u"
                    ,MDC_STR_UID_CREATOR,utc
-                   ,year,month,day,hour,minute,second);
+                   ,study_uid);
   }
 
   len = (Uint32)strlen(str);
@@ -1025,6 +1028,9 @@ char *MdcDicomWriteG0008(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   strcpy(mdcbufr,fi->series_descr); len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0008,0x103E,len,(Uint8 *)mdcbufr);
 
+  strcpy(mdcbufr,fi->operator_name); len = strlen(mdcbufr);
+  mdc_dicom_write_element(fi->ofp,0x0008,0x1070,len,(Uint8 *)mdcbufr);
+
   strcpy(mdcbufr,MDC_LIBVERS); len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0008,0x2111,len,(Uint8 *)mdcbufr);
 
@@ -1065,6 +1071,9 @@ char *MdcDicomWriteG0010(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0010,0x0040,len,(Uint8 *)mdcbufr);
 
+  sprintf(mdcbufr,"%.2f",fi->patient_height); len = strlen(mdcbufr);
+  mdc_dicom_write_element(fi->ofp,0x0010,0x1020,len,(Uint8 *)mdcbufr);
+
   sprintf(mdcbufr,"%.2f",fi->patient_weight); len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0010,0x1030,len,(Uint8 *)mdcbufr);
 
@@ -1136,17 +1145,17 @@ char *MdcDicomWriteG0020(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   pdata = fi->study_id; len = strlen(pdata);
   mdc_dicom_write_element(fi->ofp,0x0020,0x0010,len,(Uint8 *)pdata);
 
-  if (mdc_incrinstance >= 0) sprintf(mdcbufr,"%hd",mdc_incrinstance);
+  if (fi->nr_series >= 0) sprintf(mdcbufr,"%d",fi->nr_series);
   else strcpy(mdcbufr,"0");
   len = strlen(mdcbufr); 
   mdc_dicom_write_element(fi->ofp,0x0020,0x0011,len,(Uint8 *)mdcbufr);
 
-  if (fi->nr_acquisition >= 0) sprintf(mdcbufr,"%hd",fi->nr_acquisition);
+  if (fi->nr_acquisition >= 0) sprintf(mdcbufr,"%d",fi->nr_acquisition);
   else strcpy(mdcbufr,"0");
   len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0020,0x0012,len,(Uint8 *)mdcbufr);
 
-  if (fi->nr_instance >= 0) sprintf(mdcbufr,"%hd",fi->nr_instance);
+  if (fi->nr_instance >= 0) sprintf(mdcbufr,"%d",fi->nr_instance);
   else strcpy(mdcbufr,"0");
   len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0020,0x0013,len,(Uint8 *)mdcbufr);
