@@ -47,11 +47,11 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.101 2006/03/15 22:52:26 enlf Exp $ 
+/* $Id: m-files.c,v 1.104 2007/06/20 22:06:36 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -312,6 +312,9 @@ int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
 #endif
 #if MDC_INCLUDE_ECAT
     case MDC_FRMT_ECAT6: msg=MdcWriteECAT6(fi); break;
+  #if MDC_INCLUDE_TPC
+    case MDC_FRMT_ECAT7: msg=MdcWriteECAT7(fi); break;
+  #endif
 #endif
 #if MDC_INCLUDE_INTF
     case MDC_FRMT_INTF : msg=MdcWriteINTF(fi); break;
@@ -380,8 +383,9 @@ int MdcLoadFile(FILEINFO *fi)
 #endif
 #if MDC_INCLUDE_ECAT
     case MDC_FRMT_ECAT6: msg=MdcReadECAT6(fi); break;
-
+  #if MDC_INCLUDE_TPC
     case MDC_FRMT_ECAT7: msg=MdcReadECAT7(fi); break;
+  #endif
 #endif
 #if MDC_INCLUDE_INTF 
     case MDC_FRMT_INTF: msg=MdcReadINTF(fi); break;
@@ -447,6 +451,8 @@ int MdcSaveFile(FILEINFO *fi, int format, int prefixnr)
 #endif
 #if MDC_INCLUDE_ECAT
     case MDC_FRMT_ECAT6: msg=MdcWriteECAT6(fi); break;
+
+    case MDC_FRMT_ECAT7: msg=MdcWriteECAT7(fi); break;
 #endif
 #if MDC_INCLUDE_INTF
     case MDC_FRMT_INTF : msg=MdcWriteINTF(fi); break;
@@ -1101,7 +1107,7 @@ char *MdcAliasName(FILEINFO *fi, char alias[])
   char *c, *patient, *patient_id, *study;
   Int16 year, month, day;
   Int16 hour, minute, second;
-  Int16 series, acquisition, instance;
+  Int32 series, acquisition, instance;
 
   patient    = strlen(fi->patient_name) ? fi->patient_name : unknown;
   patient_id = strlen(fi->patient_id)   ? fi->patient_id   : unknown;
@@ -1121,7 +1127,7 @@ char *MdcAliasName(FILEINFO *fi, char alias[])
       acquisition = (fi->nr_acquisition > 0) ? fi->nr_acquisition : 0;
       instance = (fi->nr_instance > 0) ? fi->nr_instance : 0;
 
-      sprintf(alias,"%s+%s+%hd%02hd%02hd+%02hd%02hd%02hd+%05hd+%05hd+%05hd.ext"
+      sprintf(alias,"%s+%s+%hd%02hd%02hd+%02hd%02hd%02hd+%010d+%010d+%010d.ext"
                    ,patient,study
                    ,year,month,day
                    ,hour,minute,second
@@ -1178,6 +1184,9 @@ void MdcDefaultName(FILEINFO *fi, int format, char dest[], char *src)
 #endif
 #if MDC_INCLUDE_ECAT
    case MDC_FRMT_ECAT6: MdcNewName(dest,src,FrmtExt[MDC_FRMT_ECAT6]);  break;
+  #if MDC_INCLUDE_TPC
+   case MDC_FRMT_ECAT7: MdcNewName(dest,src,FrmtExt[MDC_FRMT_ECAT7]);  break;
+  #endif
 #endif
 #if MDC_INCLUDE_INTF
    case MDC_FRMT_INTF : MdcNewName(dest,src,FrmtExt[MDC_FRMT_INTF]);   break;
