@@ -14,11 +14,11 @@
  *                MdcHandleArgs()         - Handle the arguments           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-getopt.c,v 1.130 2006/03/01 23:21:59 enlf Exp $
+/* $Id: m-getopt.c,v 1.132 2007/06/20 22:06:36 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -98,9 +98,14 @@ void MdcPrintGlobalOptions(void)
                                         FrmtExt[MDC_FRMT_DICM]);
 #endif
 #if MDC_INCLUDE_ECAT
-  MdcPrntScrn("\t\t\"ecat\"  = %s (.%s)\n",
+  MdcPrntScrn("\t\t\"ecat6\" = %s (.%s)\n",
                                         FrmtString[MDC_FRMT_ECAT6],
                                         FrmtExt[MDC_FRMT_ECAT6]);
+  #if MDC_INCLUDE_TPC
+  MdcPrntScrn("\t\t\"ecat7\" = %s (.%s)\n",
+                                        FrmtString[MDC_FRMT_ECAT7],
+                                        FrmtExt[MDC_FRMT_ECAT7]);
+  #endif
 #endif
 #if MDC_INCLUDE_GIF
   MdcPrntScrn("\t\t\"gif\"   = %s (.%s)\n",
@@ -323,7 +328,7 @@ void MdcPrintShortInfo(void)
   }
     MdcPrntScrn(" Medical Image Conversion Utility\n");
     MdcPrntScrn("(X)MedCon %s\n",MdcGetLibShortVersion());
-    MdcPrntScrn("Copyright (C) 1997-2006 by Erik Nolf\n\n");
+    MdcPrntScrn("Copyright (C) 1997-2007 by Erik Nolf\n\n");
 
   if (XMDC_GUI == MDC_YES) {
     MdcPrntScrn("Try \'xmedcon --help\' for more information.\n\n");
@@ -620,7 +625,7 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
        MDC_FALLBACK_FRMT = MDC_FRMT_ECAT6; continue;
      }else if ( (strcasecmp(argv[a],"-byframe") == 0) ||
                 (strcasecmp(argv[a],"--sort-by-frame") == 0) ) {
-       MDC_ECAT_SORT = MDC_BYFRAME; continue;
+       MDC_ECAT6_SORT = MDC_BYFRAME; continue;
 #endif
 #if MDC_INCLUDE_DICM
      }else if ( (strcasecmp(argv[a],"-fb-dicom") == 0) ||
@@ -804,9 +809,15 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
          }else
 #endif
 #if MDC_INCLUDE_ECAT
-         if ( strcasecmp(argv[a],"ecat") == 0 ) {
+         if ( strcasecmp(argv[a],"ecat") == 0 ||
+              strcasecmp(argv[a],"ecat6") == 0 ) {
              convs[MDC_FRMT_ECAT6]+=1; total[MDC_CONVS]+=1;
          }else
+  #if MDC_INCLUDE_TPC
+         if ( strcasecmp(argv[a],"ecat7") == 0 ) {
+             convs[MDC_FRMT_ECAT7]+=1; total[MDC_CONVS]+=1;
+         }else
+  #endif
 #endif
 #if MDC_INCLUDE_INTF
          if ( strcasecmp(argv[a],"intf") == 0 ) {
@@ -879,10 +890,17 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
            }else
 #endif
 #if MDC_INCLUDE_ECAT
-           if ( strcasecmp(argv[a],"ecat") == 0) {
-             MdcPrntErr(MDC_NO_CODE,"ECAT is unsupported in pipes (seek)");
+           if ( strcasecmp(argv[a],"ecat") == 0 ||
+                strcasecmp(argv[a],"ecat6") == 0 ) {
+             MdcPrntErr(MDC_NO_CODE,"ECAT6 is unsupported in pipes (seek)");
              DO_STDIN = MDC_YES; MDC_FRMT_INPUT = MDC_FRMT_ECAT6;
            }else
+  #if MDC_INCLUDE_TPC
+           if ( strcasecmp(argv[a],"ecat7") == 0) {
+             MdcPrntErr(MDC_NO_CODE,"ECAT7 is unsupported in pipes");
+             DO_STDIN = MDC_YES; MDC_FRMT_INPUT = MDC_FRMT_ECAT7;
+           }else
+  #endif
 #endif
 #if MDC_INCLUDE_INTF
            if ( strcasecmp(argv[a],"intf") == 0) {
