@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.71 2006/03/01 23:21:59 enlf Exp $
+/* $Id: m-global.c,v 1.75 2007/06/20 22:06:36 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -41,9 +41,9 @@
 ****************************************************************************/
 
 /* all our version constants */
-const Uint32 MDC_MAJOR = XMEDCON_MAJOR;
-const Uint32 MDC_MINOR = XMEDCON_MINOR;
-const Uint32 MDC_MICRO = XMEDCON_MICRO;
+const char  *MDC_MAJOR = XMEDCON_MAJOR;
+const char  *MDC_MINOR = XMEDCON_MINOR;
+const char  *MDC_MICRO = XMEDCON_MICRO;
 const char  *MDC_PRGR  = XMEDCON_PRGR;
 const char  *MDC_DATE  = XMEDCON_DATE;
 const char  *MDC_VERSION = XMEDCON_VERSION;
@@ -97,7 +97,7 @@ char FrmtExt[MDC_MAX_FRMTS][8] = {
     "ima",    /* MDC_FRMT_ACR   */
     "im",     /* MDC_FRMT_INW   */
     "img",    /* MDC_FRMT_ECAT6 */
-    "iv",     /* MDC_FRMT_ECAT7 */
+    "v",      /* MDC_FRMT_ECAT7 */
     "h33",    /* MDC_FRMT_INTF  */
     "hdr",    /* MDC_FRMT_ANLZ  */
     "dcm",    /* MDC_FRMT_DICM  */
@@ -206,7 +206,7 @@ Int8 MDC_CROP_IMAGES     = MDC_NO;      /* crop image dimensions            */
 Int8 MDC_RESLICE = MDC_NO;              /* reslice images (tra, sag, cor)   */
 
 Int8 MDC_FRMT_INPUT = MDC_FRMT_NONE;    /* format used for stdin            */ 
-Int8 MDC_ECAT_SORT = MDC_ANATOMICAL;    /* ECAT sort order                  */
+Int8 MDC_ECAT6_SORT = MDC_ANATOMICAL;   /* ECAT sort order                  */
 
 #if   MDC_INCLUDE_DICM                  /* fallback read format             */
 Int8 MDC_FALLBACK_FRMT = MDC_FRMT_DICM;
