@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.h,v 1.58 2006/03/01 23:21:59 enlf Exp $
+/* $Id: m-global.h,v 1.61 2007/06/18 20:46:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -35,9 +35,9 @@
                               D E F I N E S 
 ****************************************************************************/
 
-extern const Uint32 MDC_MAJOR;
-extern const Uint32 MDC_MINOR;
-extern const Uint32 MDC_MICRO;
+extern const char *MDC_MAJOR;
+extern const char *MDC_MINOR;
+extern const char *MDC_MICRO;
 extern const char *MDC_PRGR;
 extern const char *MDC_DATE;
 extern const char *MDC_VERSION;
@@ -115,7 +115,7 @@ extern Int8 MDC_WRITE_ENDIAN;
 extern Int8 MDC_MY_DEBUG;
 extern Int8 MDC_INFO_DB;
 extern Int8 MDC_HACK_ACR;
-extern Int8 MDC_ECAT_SORT;
+extern Int8 MDC_ECAT6_SORT;
 extern Int8 MDC_FALLBACK_FRMT;
 
 
