@@ -37,11 +37,11 @@
  *                MdcCleanUpFI()        - Clean up FILEINFO struct         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.c,v 1.72 2006/12/05 22:44:43 enlf Exp $ 
+/* $Id: m-structs.c,v 1.74 2007/06/05 21:01:25 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -468,6 +468,7 @@ void MdcInitFI(FILEINFO *fi, char *path)
    strcpy(fi->patient_id,"Unknown");
    strcpy(fi->patient_sex,"Unknown");
    strcpy(fi->patient_dob,"00000000");
+   strcpy(fi->operator_name,"Unknown");
    strcpy(fi->study_descr,"Unknown");
    strcpy(fi->study_id,"Unknown");
    strcpy(fi->institution,MDC_INSTITUTION);
@@ -479,6 +480,7 @@ void MdcInitFI(FILEINFO *fi, char *path)
    strcpy(fi->isotope_code,"Unknown");
  
    fi->patient_weight   = 0.;
+   fi->patient_height   = 0.;
    fi->isotope_halflife = 0.;
    fi->injected_dose    = 0.;
    fi->gantry_tilt      = 0.;
@@ -767,6 +769,7 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   strncpy(dest->patient_name,src->patient_name,MDC_MAXSTR);
   strncpy(dest->patient_id,src->patient_id,MDC_MAXSTR);
   strncpy(dest->patient_dob,src->patient_dob,MDC_MAXSTR);
+  strncpy(dest->operator_name,src->operator_name,MDC_MAXSTR);
   strncpy(dest->study_descr,src->study_descr,MDC_MAXSTR);
   strncpy(dest->study_id,src->study_id,MDC_MAXSTR);
 
@@ -798,6 +801,7 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   strncpy(dest->isotope_code,src->isotope_code,MDC_MAXSTR);
 
   dest->patient_weight   = src->patient_weight;
+  dest->patient_height   = src->patient_height;
   dest->isotope_halflife = src->isotope_halflife;
   dest->gantry_tilt      = src->gantry_tilt;
   dest->injected_dose    = src->injected_dose;
