@@ -26,11 +26,11 @@
  *                XMdcRawPredefSelOpen()            - Raw Predef Load      * 
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfilesel.c,v 1.30 2006/03/01 23:21:59 enlf Exp $
+/* $Id: xfilesel.c,v 1.32 2007/06/20 22:06:36 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -285,6 +285,22 @@ void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
 
     gtk_menu_append(GTK_MENU(menu),menuitem);
     gtk_widget_show(menuitem);
+  #if MDC_INCLUDE_TPC
+    if (LOOK && (format == MDC_FRMT_ECAT7)) {
+      XMDC_WRITE_FRMT = MDC_FRMT_ECAT7; LOOK = MDC_NO; selected = item;
+    }
+    format_to_use[MDC_FRMT_ECAT7]=MDC_FRMT_ECAT7;
+    mitem_nr[MDC_FRMT_ECAT7] = item++;
+
+    menuitem = gtk_menu_item_new_with_label(FrmtString[MDC_FRMT_ECAT7]);
+
+    gtk_signal_connect( GTK_OBJECT(menuitem), "activate",
+                        GTK_SIGNAL_FUNC(XMdcFileSelSaveCallbackFormatMenu),
+                        &format_to_use[MDC_FRMT_ECAT7]);
+
+    gtk_menu_append(GTK_MENU(menu),menuitem);
+    gtk_widget_show(menuitem);
+  #endif
 #endif
 #if MDC_INCLUDE_GIF
     if (LOOK && (format == MDC_FRMT_GIF)) {
