@@ -11,11 +11,11 @@
  *                XMdcShowFileInfo()        - Display general file info    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.c,v 1.57 2006/03/01 23:21:59 enlf Exp $
+/* $Id: xinfo.c,v 1.60 2007/06/05 21:15:55 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -486,9 +486,13 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"patient_weight: %.2f [kg]\n",my.fi->patient_weight);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"patient_height: %.2f [m]\n",my.fi->patient_height);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
 
   sprintf(xmdcstr,"\nStudy Information\n");
   gtk_text_insert(GTK_TEXT(text),NULL,&Blue,NULL,xmdcstr,-1); 
+  sprintf(xmdcstr,"operator_name    : %s\n",my.fi->operator_name);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"study_descr      : %s\n",my.fi->study_descr);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"study_id         : %s\n",my.fi->study_id);
