@@ -12,11 +12,11 @@
  * Functions    : XMdcMenusGetMain()      - Get main menu                  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xmnuftry.c,v 1.30 2006/03/01 23:21:59 enlf Exp $
+/* $Id: xmnuftry.c,v 1.32 2007/06/20 22:06:36 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -77,6 +77,9 @@ static GtkItemFactoryEntry menu_items[] = {
 #endif
 #if MDC_INCLUDE_ECAT
   {(char *)"/File/Save As/Ecat6",     NULL,XMdcFileSelSave,MDC_FRMT_ECAT6,NULL},
+  #if MDC_INCLUDE_TPC
+  {(char *)"/File/Save As/Ecat7",     NULL,XMdcFileSelSave,MDC_FRMT_ECAT7,NULL},
+  #endif
 #endif
 #if MDC_INCLUDE_GIF
   {(char *)"/File/Save As/Gif89a",    NULL,XMdcFileSelSave,MDC_FRMT_GIF,NULL},
