@@ -32,11 +32,11 @@
  *                Imlib by Rasterman                                       *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xutils.c,v 1.24 2006/03/01 23:22:00 enlf Exp $
+/* $Id: xutils.c,v 1.28 2007/05/27 21:08:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2006 by Erik Nolf
+   Copyright (C) 1997-2007 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -358,9 +358,13 @@ void XMdcToggleVisibility(GtkWidget *widget)
 }
 
 void XMdcSetImageScales(void)
-{
+{ 
+  float ratio_width, ratio_height;
+
   my.scale_width = 1.; my.scale_height = 1.;
 
+  /* scale to real world sizes */
+
   if (my.fi->pixdim[1] > my.fi->pixdim[2]) {
 
     /* width > height -> height is unit */
@@ -373,6 +377,27 @@ void XMdcSetImageScales(void)
 
   }
 
+  /* fit to screen sizes */
+
+  ratio_width = ((float)my.fi->mwidth * my.scale_width)
+           / ((float)gdk_screen_width()  - (1.2 * (float)XMDC_FREE_BORDER));
+
+  ratio_height = ((float)my.fi->mheight * my.scale_height)
+           / ((float)gdk_screen_height() - (1.2 * (float)XMDC_FREE_BORDER)); 
+
+  if ((ratio_width <= 1.) && (ratio_height <= 1.)) return; /* both fit */
+
+  /* needs resizing */
+  if (ratio_width > ratio_height) {
+    /* fit via width */
+    my.scale_width  /= ratio_width;
+    my.scale_height /= ratio_width;
+  }else{
+    /* fit via height */
+    my.scale_width  /= ratio_height;
+    my.scale_height /= ratio_height;
+  } 
+
 }
 
 Uint32 XMdcScaleW(Uint32 width)
